@@ -2,7 +2,6 @@ from sqlalchemy import Column, Integer, String, Float, Boolean, ForeignKey, Date
 from sqlalchemy.orm import relationship
 
 from univer_db.orm import get_base
-from univer_db.models import PaymentForm
 
 
 Base = get_base()
@@ -366,18 +365,18 @@ class TeacherChairLink(Base):
     __tablename__ = 'univer_teacher_chair_link'
 
     # Преподаватель
-    teacher_id = Column(ForeignKey('univer_teacher.teacher_id'))
+    teacher_id = Column(ForeignKey('univer_teacher.teacher_id'), primary_key=True)
     teacher = relationship('Teacher')
 
     # Кафедра
-    chair_id = Column(ForeignKey('univer_chair.chair_id'))
+    chair_id = Column(ForeignKey('univer_chair.chair_id'), primary_key=True)
     chair = relationship('Chair')
 
     # Ставка
     rate = Column('stavka', Integer)
 
     def __repr__(self):
-        return '<TeacherChairLink {} (id={})>'.format(self, self.id)
+        return '<TeacherChairLink {}>'.format(self)
 
     def __str__(self):
-        return f"{self.chair}: {self.teacher}"
+        return f'{self.chair}: {self.teacher}'
